/*
 * Copyright (C) 2001 by Stefan Matthias Aust. All rights reserved.
 */
package sma.projects.game;

import java.io.*;
import java.net.*;
import java.util.*;

public class Dungeon {

    static class Field {
        static final int FLOOR = 1;
        static final int TREE = 2;
        static final int WALL = 3;

        int type;
        Hero hero;
    }

    private Field[][] fields;

    Dungeon(int width, int height) {
        fields = new Field[width][height];
        for (int x = 0; x < width; x++)
            for (int y = 0; y < height; y++)
                fields[x][y] = new Field();
    }

    int getWidth() {
        return fields.length;
    }

    int getHeight() {
        return fields[0].length;
    }

    void createLevel(Random r) {
        int width = fields.length;
        int height = fields[0].length;
        fill(0, 0, width, 1, Field.WALL);
        fill(0, height - 1, width, 1, Field.WALL);
        fill(0, 1, 1, height - 2, Field.WALL);
        fill(width - 1, 1, 1, height - 2, Field.WALL);

        fill(1, 1, width - 2, height - 2, Field.FLOOR);

        for (int i = 0; i < width * height / 10; i++)
            setType(r.nextInt(width - 2) + 1, r.nextInt(height - 2) + 1, Field.TREE);
    }

    void fill(int x, int y, int w, int h, int type) {
        for (int j = 0; j < h; j++)
            for (int i = 0; i < w; i++)
                setType(x + i, y + j, type);
    }

    public Hero getHero(int x, int y) {
        return fields[x][y].hero;
    }

    public void setHero(int x, int y, Hero hero) {
        fields[x][y].hero = hero;
    }

    public int getType(int x, int y) {
        return fields[x][y].type;
    }

    public void setType(int x, int y, int type) {
        fields[x][y].type = type;
    }

    int getHType(int x, int y) {
        if (x < 0 || y < 0 || x >= getWidth() || y >= getHeight())
            return 0;
        if (fields[x][y].hero != null)
            return 4;
        return fields[x][y].type;
    }

}