/*
 * Copyright (C) 2001 by Stefan Matthias Aust. All rights reserved.
 */
package sma.projects.game;

import java.io.*;
import java.net.*;
import java.util.*;

public class Hero {
    private int x, y;
    private Dungeon map;

    public Hero(Dungeon map) {
        this.map = map;
    }

    // ----------------------------------------------------------------------

    public void goNorth() {
        go(x, y - 1);
    }

    public void goSouth() {
        go(x, y + 1);
    }

    public void goWest() {
        go(x - 1, y);
    }

    public void goEast() {
        go(x + 1, y);
    }

    public void go(int nx, int ny) {
        if (canEnter(nx, ny)) {
            map.setHero(x, y, null);
            x = nx;
            y = ny;
            map.setHero(x, y, this);
        }
    }

    public boolean canEnter(int x, int y) {
        return map.getHType(x, y) == Dungeon.Field.FLOOR;
    }

    // ----------------------------------------------------------------------

    private static final int SIZE = 225;
    private int[] oldTileCodes = new int[SIZE];
    private int[] newTileCodes = new int[SIZE];

    public void sendTileCodes(DataOutputStream out) throws IOException {
        getTileCodes(newTileCodes);
        for (int i = 0; i < SIZE; i++)
            if (oldTileCodes[i] != newTileCodes[i]) {
                for (int j = 0; j < SIZE; j++)
                    out.writeInt(newTileCodes[j]);
                out.flush();
                int[] temp = oldTileCodes;
                oldTileCodes = newTileCodes;
                newTileCodes = temp;
                return;
            }
    }

    private void getTileCodes(int[] tileCodes) {
        // carefully pick correct window (TODO: simplify)
        int y1 = Math.min(y + 8, map.getHeight());
        int x1 = Math.min(x + 8, map.getWidth());
        int y0 = Math.max(y1 - 15, Math.min(0, map.getHeight() - 15) / 2);
        int x0 = Math.max(x1 - 15, Math.min(0, map.getWidth() - 15) / 2);
        y1 = y0 + 15;
        x1 = x0 + 15;

        int i = 0;
        for (int yy = y0; yy < y1; yy++)
            for (int xx = x0; xx < x1; xx++)
                tileCodes[i++] = map.getHType(xx, yy);
    }
}